==> niftygate-0.6.0.crate: niftygate-0.6.0/src/openzeppelin/contracts_upgradeable/generated.rs <==
#![allow(clippy::all)]

pub mod access_control_enumerable_upgradeable;
pub mod access_control_upgradeable;
pub mod address_upgradeable;
pub mod arrays_upgradeable;
pub mod bit_maps_upgradeable;
pub mod clones_upgradeable;
pub mod conditional_escrow_upgradeable;
pub mod context_upgradeable;
pub mod counters_upgradeable;
pub mod create2_upgradeable;
pub mod ecdsa_upgradeable;
pub mod eip712_upgradeable;
pub mod enumerable_map_upgradeable;
pub mod enumerable_set_upgradeable;
pub mod erc1155_burnable_upgradeable;
pub mod erc1155_holder_upgradeable;
pub mod erc1155_pausable_upgradeable;
pub mod erc1155_preset_minter_pauser_upgradeable;
pub mod erc1155_receiver_upgradeable;
pub mod erc1155_supply_upgradeable;
pub mod erc1155_upgradeable;
pub mod erc165_checker_upgradeable;
pub mod erc165_storage_upgradeable;
pub mod erc165_upgradeable;
pub mod erc1820_implementer_upgradeable;
pub mod erc1967_upgrade_upgradeable;
pub mod erc20_burnable_upgradeable;
pub mod erc20_capped_upgradeable;
pub mod erc20_flash_mint_upgradeable;
pub mod erc20_pausable_upgradeable;
pub mod erc20_permit_upgradeable;
pub mod erc20_preset_fixed_supply_upgradeable;
pub mod erc20_preset_minter_pauser_upgradeable;
pub mod erc20_snapshot_upgradeable;
pub mod erc20_upgradeable;
pub mod erc20_votes_comp_upgradeable;
pub mod erc20_votes_upgradeable;
pub mod erc20_wrapper_upgradeable;
pub mod erc2771_context_upgradeable;
pub mod erc721_burnable_upgradeable;
pub mod erc721_enumerable_upgradeable;
pub mod erc721_holder_upgradeable;
pub mod erc721_pausable_upgradeable;
pub mod erc721_preset_minter_pauser_auto_id_upgradeable;
pub mod erc721_upgradeable;
pub mod erc721uri_storage_upgradeable;
pub mod erc777_preset_fixed_supply_upgradeable;
pub mod erc777_upgradeable;
pub mod escrow_upgradeable;
pub mod i_access_control_enumerable_upgradeable;
pub mod i_access_control_upgradeable;
pub mod i_beacon_upgradeable;
pub mod ierc1155_metadata_uri_upgradeable;
pub mod ierc1155_receiver_upgradeable;
pub mod ierc1155_upgradeable;
pub mod ierc1271_upgradeable;
pub mod ierc165_upgradeable;
pub mod ierc1820_implementer_upgradeable;
pub mod ierc1820_registry_upgradeable;
pub mod ierc20_metadata_upgradeable;
pub mod ierc20_permit_upgradeable;
pub mod ierc20_upgradeable;
pub mod ierc3156_flash_borrower_upgradeable;
pub mod ierc3156_flash_lender_upgradeable;
pub mod ierc721_enumerable_upgradeable;
pub mod ierc721_metadata_upgradeable;
pub mod ierc721_receiver_upgradeable;
pub mod ierc721_upgradeable;
pub mod ierc777_recipient_upgradeable;
pub mod ierc777_sender_upgradeable;
pub mod ierc777_upgradeable;
pub mod initializable;
pub mod math_upgradeable;
pub mod merkle_proof_upgradeable;
pub mod minimal_forwarder_upgradeable;
pub mod multicall_upgradeable;
pub mod ownable_upgradeable;
pub mod pausable_upgradeable;
pub mod payment_splitter_upgradeable;
pub mod pull_payment_upgradeable;
pub mod reentrancy_guard_upgradeable;
pub mod refund_escrow_upgradeable;
pub mod safe_cast_upgradeable;
pub mod safe_erc20_upgradeable;
pub mod safe_math_upgradeable;
pub mod signature_checker_upgradeable;
pub mod signed_safe_math_upgradeable;
pub mod storage_slot_upgradeable;
pub mod strings_upgradeable;
pub mod timelock_controller_upgradeable;
pub mod token_timelock_upgradeable;
pub mod uups_upgradeable;

pub use access_control_enumerable_upgradeable::*;
pub use access_control_upgradeable::*;
pub use address_upgradeable::*;
pub use arrays_upgradeable::*;
pub use bit_maps_upgradeable::*;
pub use clones_upgradeable::*;
pub use conditional_escrow_upgradeable::*;
pub use context_upgradeable::*;
pub use counters_upgradeable::*;
pub use create2_upgradeable::*;
pub use ecdsa_upgradeable::*;
pub use eip712_upgradeable::*;
pub use enumerable_map_upgradeable::*;
pub use enumerable_set_upgradeable::*;
pub use erc1155_burnable_upgradeable::*;
pub use erc1155_holder_upgradeable::*;
pub use erc1155_pausable_upgradeable::*;
pub use erc1155_preset_minter_pauser_upgradeable::*;
pub use erc1155_receiver_upgradeable::*;
pub use erc1155_supply_upgradeable::*;
pub use erc1155_upgradeable::*;
pub use erc165_checker_upgradeable::*;
pub use erc165_storage_upgradeable::*;
pub use erc165_upgradeable::*;
pub use erc1820_implementer_upgradeable::*;
pub use erc1967_upgrade_upgradeable::*;
pub use erc20_burnable_upgradeable::*;
pub use erc20_capped_upgradeable::*;
pub use erc20_flash_mint_upgradeable::*;
pub use erc20_pausable_upgradeable::*;
pub use erc20_permit_upgradeable::*;
pub use erc20_preset_fixed_supply_upgradeable::*;
pub use erc20_preset_minter_pauser_upgradeable::*;
pub use erc20_snapshot_upgradeable::*;
pub use erc20_upgradeable::*;
pub use erc20_votes_comp_upgradeable::*;
pub use erc20_votes_upgradeable::*;
pub use erc20_wrapper_upgradeable::*;
pub use erc2771_context_upgradeable::*;
pub use erc721_burnable_upgradeable::*;
pub use erc721_enumerable_upgradeable::*;
pub use erc721_holder_upgradeable::*;
pub use erc721_pausable_upgradeable::*;
pub use erc721_preset_minter_pauser_auto_id_upgradeable::*;
pub use erc721_upgradeable::*;
pub use erc721uri_storage_upgradeable::*;
pub use erc777_preset_fixed_supply_upgradeable::*;
pub use erc777_upgradeable::*;
pub use escrow_upgradeable::*;
pub use i_access_control_enumerable_upgradeable::*;
pub use i_access_control_upgradeable::*;
pub use i_beacon_upgradeable::*;
pub use ierc1155_metadata_uri_upgradeable::*;
pub use ierc1155_receiver_upgradeable::*;
pub use ierc1155_upgradeable::*;
pub use ierc1271_upgradeable::*;
pub use ierc165_upgradeable::*;
pub use ierc1820_implementer_upgradeable::*;
pub use ierc1820_registry_upgradeable::*;
pub use ierc20_metadata_upgradeable::*;
pub use ierc20_permit_upgradeable::*;
pub use ierc20_upgradeable::*;
pub use ierc3156_flash_borrower_upgradeable::*;
pub use ierc3156_flash_lender_upgradeable::*;
pub use ierc721_enumerable_upgradeable::*;
pub use ierc721_metadata_upgradeable::*;
pub use ierc721_receiver_upgradeable::*;
pub use ierc721_upgradeable::*;
pub use ierc777_recipient_upgradeable::*;
pub use ierc777_sender_upgradeable::*;
pub use ierc777_upgradeable::*;
pub use initializable::*;
pub use math_upgradeable::*;
pub use merkle_proof_upgradeable::*;
pub use minimal_forwarder_upgradeable::*;
pub use multicall_upgradeable::*;
pub use ownable_upgradeable::*;
pub use pausable_upgradeable::*;
pub use payment_splitter_upgradeable::*;
pub use pull_payment_upgradeable::*;
pub use reentrancy_guard_upgradeable::*;
pub use refund_escrow_upgradeable::*;
pub use safe_cast_upgradeable::*;
pub use safe_erc20_upgradeable::*;
pub use safe_math_upgradeable::*;
pub use signature_checker_upgradeable::*;
pub use signed_safe_math_upgradeable::*;
pub use storage_slot_upgradeable::*;
pub use strings_upgradeable::*;
pub use timelock_controller_upgradeable::*;
pub use token_timelock_upgradeable::*;
pub use uups_upgradeable::*;

==> niftygate-0.6.1.crate: niftygate-0.6.1/src/openzeppelin/contracts_upgradeable/generated.rs <==
#![allow(clippy::all)]

pub mod access_control_enumerable_upgradeable;
pub mod access_control_upgradeable;
pub mod address_upgradeable;
pub mod arrays_upgradeable;
pub mod bit_maps_upgradeable;
pub mod clones_upgradeable;
pub mod conditional_escrow_upgradeable;
pub mod context_upgradeable;
pub mod counters_upgradeable;
pub mod create2_upgradeable;
pub mod ecdsa_upgradeable;
pub mod eip712_upgradeable;
pub mod enumerable_map_upgradeable;
pub mod enumerable_set_upgradeable;
pub mod erc1155_burnable_upgradeable;
pub mod erc1155_holder_upgradeable;
pub mod erc1155_pausable_upgradeable;
pub mod erc1155_preset_minter_pauser_upgradeable;
pub mod erc1155_receiver_upgradeable;
pub mod erc1155_supply_upgradeable;
pub mod erc1155_upgradeable;
pub mod erc165_checker_upgradeable;
pub mod erc165_storage_upgradeable;
pub mod erc165_upgradeable;
pub mod erc1820_implementer_upgradeable;
pub mod erc1967_upgrade_upgradeable;
pub mod erc20_burnable_upgradeable;
pub mod erc20_capped_upgradeable;
pub mod erc20_flash_mint_upgradeable;
pub mod erc20_pausable_upgradeable;
pub mod erc20_permit_upgradeable;
pub mod erc20_preset_fixed_supply_upgradeable;
pub mod erc20_preset_minter_pauser_upgradeable;
pub mod erc20_snapshot_upgradeable;
pub mod erc20_upgradeable;
pub mod erc20_votes_comp_upgradeable;
pub mod erc20_votes_upgradeable;
pub mod erc20_wrapper_upgradeable;
pub mod erc2771_context_upgradeable;
pub mod erc721_burnable_upgradeable;
pub mod erc721_enumerable_upgradeable;
pub mod erc721_holder_upgradeable;
pub mod erc721_pausable_upgradeable;
pub mod erc721_preset_minter_pauser_auto_id_upgradeable;
pub mod erc721_upgradeable;
pub mod erc721uri_storage_upgradeable;
pub mod erc777_preset_fixed_supply_upgradeable;
pub mod erc777_upgradeable;
pub mod escrow_upgradeable;
pub mod governor_compatibility_bravo_upgradeable;
pub mod governor_counting_simple_upgradeable;
pub mod governor_proposal_threshold_upgradeable;
pub mod governor_timelock_compound_upgradeable;
pub mod governor_timelock_control_upgradeable;
pub mod governor_upgradeable;
pub mod governor_votes_comp_upgradeable;
pub mod governor_votes_quorum_fraction_upgradeable;
pub mod governor_votes_upgradeable;
pub mod i_access_control_enumerable_upgradeable;
pub mod i_access_control_upgradeable;
pub mod i_beacon_upgradeable;
pub mod i_compound_timelock_upgradeable;
pub mod i_governor_compatibility_bravo_upgradeable;
pub mod i_governor_timelock_upgradeable;
pub mod i_governor_upgradeable;
pub mod ierc1155_metadata_uri_upgradeable;
pub mod ierc1155_receiver_upgradeable;
pub mod ierc1155_upgradeable;
pub mod ierc1271_upgradeable;
pub mod ierc1363_receiver_upgradeable;
pub mod ierc1363_spender_upgradeable;
pub mod ierc1363_upgradeable;
pub mod ierc165_upgradeable;
pub mod ierc1820_implementer_upgradeable;
pub mod ierc1820_registry_upgradeable;
pub mod ierc20_metadata_upgradeable;
pub mod ierc20_permit_upgradeable;
pub mod ierc20_upgradeable;
pub mod ierc2612_upgradeable;
pub mod ierc2981_upgradeable;
pub mod ierc3156_flash_borrower_upgradeable;
pub mod ierc3156_flash_lender_upgradeable;
pub mod ierc721_enumerable_upgradeable;
pub mod ierc721_metadata_upgradeable;
pub mod ierc721_receiver_upgradeable;
pub mod ierc721_upgradeable;
pub mod ierc777_recipient_upgradeable;
pub mod ierc777_sender_upgradeable;
pub mod ierc777_upgradeable;
pub mod initializable;
pub mod math_upgradeable;
pub mod merkle_proof_upgradeable;
pub mod minimal_forwarder_upgradeable;
pub mod multicall_upgradeable;
pub mod ownable_upgradeable;
pub mod pausable_upgradeable;
pub mod payment_splitter_upgradeable;
pub mod pull_payment_upgradeable;
pub mod reentrancy_guard_upgradeable;
pub mod refund_escrow_upgradeable;
pub mod safe_cast_upgradeable;
pub mod safe_erc20_upgradeable;
pub mod safe_math_upgradeable;
pub mod signature_checker_upgradeable;
pub mod signed_safe_math_upgradeable;
pub mod storage_slot_upgradeable;
pub mod strings_upgradeable;
pub mod timelock_controller_upgradeable;
pub mod timers_upgradeable;
pub mod token_timelock_upgradeable;
pub mod uups_upgradeable;

pub use access_control_enumerable_upgradeable::*;
pub use access_control_upgradeable::*;
pub use address_upgradeable::*;
pub use arrays_upgradeable::*;
pub use bit_maps_upgradeable::*;
pub use clones_upgradeable::*;
pub use conditional_escrow_upgradeable::*;
pub use context_upgradeable::*;
pub use counters_upgradeable::*;
pub use create2_upgradeable::*;
pub use ecdsa_upgradeable::*;
pub use eip712_upgradeable::*;
pub use enumerable_map_upgradeable::*;
pub use enumerable_set_upgradeable::*;
pub use erc1155_burnable_upgradeable::*;
pub use erc1155_holder_upgradeable::*;
pub use erc1155_pausable_upgradeable::*;
pub use erc1155_preset_minter_pauser_upgradeable::*;
pub use erc1155_receiver_upgradeable::*;
pub use erc1155_supply_upgradeable::*;
pub use erc1155_upgradeable::*;
pub use erc165_checker_upgradeable::*;
pub use erc165_storage_upgradeable::*;
pub use erc165_upgradeable::*;
pub use erc1820_implementer_upgradeable::*;
pub use erc1967_upgrade_upgradeable::*;
pub use erc20_burnable_upgradeable::*;
pub use erc20_capped_upgradeable::*;
pub use erc20_flash_mint_upgradeable::*;
pub use erc20_pausable_upgradeable::*;
pub use erc20_permit_upgradeable::*;
pub use erc20_preset_fixed_supply_upgradeable::*;
pub use erc20_preset_minter_pauser_upgradeable::*;
pub use erc20_snapshot_upgradeable::*;
pub use erc20_upgradeable::*;
pub use erc20_votes_comp_upgradeable::*;
pub use erc20_votes_upgradeable::*;
pub use erc20_wrapper_upgradeable::*;
pub use erc2771_context_upgradeable::*;
pub use erc721_burnable_upgradeable::*;
pub use erc721_enumerable_upgradeable::*;
pub use erc721_holder_upgradeable::*;
pub use erc721_pausable_upgradeable::*;
pub use erc721_preset_minter_pauser_auto_id_upgradeable::*;
pub use erc721_upgradeable::*;
pub use erc721uri_storage_upgradeable::*;
pub use erc777_preset_fixed_supply_upgradeable::*;
pub use erc777_upgradeable::*;
pub use escrow_upgradeable::*;
pub use governor_compatibility_bravo_upgradeable::*;
pub use governor_counting_simple_upgradeable::*;
pub use governor_proposal_threshold_upgradeable::*;
pub use governor_timelock_compound_upgradeable::*;
pub use governor_timelock_control_upgradeable::*;
pub use governor_upgradeable::*;
pub use governor_votes_comp_upgradeable::*;
pub use governor_votes_quorum_fraction_upgradeable::*;
pub use governor_votes_upgradeable::*;
pub use i_access_control_enumerable_upgradeable::*;
pub use i_access_control_upgradeable::*;
pub use i_beacon_upgradeable::*;
pub use i_compound_timelock_upgradeable::*;
pub use i_governor_compatibility_bravo_upgradeable::*;
pub use i_governor_timelock_upgradeable::*;
pub use i_governor_upgradeable::*;
pub use ierc1155_metadata_uri_upgradeable::*;
pub use ierc1155_receiver_upgradeable::*;
pub use ierc1155_upgradeable::*;
pub use ierc1271_upgradeable::*;
pub use ierc1363_receiver_upgradeable::*;
pub use ierc1363_spender_upgradeable::*;
pub use ierc1363_upgradeable::*;
pub use ierc165_upgradeable::*;
pub use ierc1820_implementer_upgradeable::*;
pub use ierc1820_registry_upgradeable::*;
pub use ierc20_metadata_upgradeable::*;
pub use ierc20_permit_upgradeable::*;
pub use ierc20_upgradeable::*;
pub use ierc2612_upgradeable::*;
pub use ierc2981_upgradeable::*;
pub use ierc3156_flash_borrower_upgradeable::*;
pub use ierc3156_flash_lender_upgradeable::*;
pub use ierc721_enumerable_upgradeable::*;
pub use ierc721_metadata_upgradeable::*;
pub use ierc721_receiver_upgradeable::*;
pub use ierc721_upgradeable::*;
pub use ierc777_recipient_upgradeable::*;
pub use ierc777_sender_upgradeable::*;
pub use ierc777_upgradeable::*;
pub use initializable::*;
pub use math_upgradeable::*;
pub use merkle_proof_upgradeable::*;
pub use minimal_forwarder_upgradeable::*;
pub use multicall_upgradeable::*;
pub use ownable_upgradeable::*;
pub use pausable_upgradeable::*;
pub use payment_splitter_upgradeable::*;
pub use pull_payment_upgradeable::*;
pub use reentrancy_guard_upgradeable::*;
pub use refund_escrow_upgradeable::*;
pub use safe_cast_upgradeable::*;
pub use safe_erc20_upgradeable::*;
pub use safe_math_upgradeable::*;
pub use signature_checker_upgradeable::*;
pub use signed_safe_math_upgradeable::*;
pub use storage_slot_upgradeable::*;
pub use strings_upgradeable::*;
pub use timelock_controller_upgradeable::*;
pub use timers_upgradeable::*;
pub use token_timelock_upgradeable::*;
pub use uups_upgradeable::*;
